areYouSureYouWantToCancelTheTransaction property
Implementation
static String areYouSureYouWantToCancelTheTransaction =
"Are you sure you want to cancel the transaction?";
static String areYouSureYouWantToCancelTheTransaction =
"Are you sure you want to cancel the transaction?";